<?php

namespace Schaffen\Transaction\Transaction\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Database\Eloquent\SoftDeletes;
use Schaffen\Core\Person\Models\Person;
use Schaffen\Core\Product\Models\ProductVarietyPack;
use Schaffen\Core\Product\Traits\HasProduct;

class TransactionItem extends Model
{

   use SoftDeletes, HasProduct;

   const CREATED_AT = 'trit_created_at';
   const UPDATED_AT = 'trit_updated_at';
   const DELETED_AT = 'trit_deleted_at';
   public $prefix = 'trit';
   public $timestamps = true;
   protected $table = "transacao.transacao_item";
   protected $primaryKey = "trit_codigo";
   protected $fillable = [
      "trit_quantidade",
      "trit_valor_unitario",
      "trit_serial"
   ];

   protected $dates = [
      "trit_created_at",
      "trit_updated_at",
      "trit_deleted_at"
   ];
   public $with = ["desconto"];
   public function trasacao()
   {
      return $this->belongsTo(Transaction::class, "trit_fk_trn_codigo", "trn_codigo");
   }

   public function desconto()
   {
      return $this->hasOne(TransactionItemDiscount::class, "trid_fk_trit_codigo");
   }

   public function entregas()
   {
      return $this->hasMany(TransactionItemDelivery::class, "trie_fk_trit_codigo");
   }

   public function produtos()
   {
      return $this->hasMany(ProductVarietyPack::class, "pve_codigo");
   }

   public function responsavel()
   {
      return $this->belongsTo(Person::class, "trit_responsavel_fk_pes_codigo", "pes_codigo");
   }



   /*public function getTritQuantidadeAttribute($value)
   {
      return number_format($value, 2) ;
   }*/

}
